| Title: | Example point count data set with paired human and ARU data |
|---|---|
| Description: | Data set from Van Wilgenburg et al. 2016 <doi:10.5751/ACE-00975-120113>. |
| Authors: | Peter Solymos [cre, aut], Steven L. Van Wilgenburg [aut] |
| Maintainer: | Peter Solymos <[email protected]> |
| License: | CC BY-SA 4.0 |
| Version: | 0.0-1 |
| Built: | 2026-05-13 07:04:33 UTC |
| Source: | https://github.com/borealbirds/paired |
Data set from Van Wilgenburg et al. 2016 <doi:10.5751/ACE-00975-120113>.
data("paired")data("paired")
A data frame with 11340 observations on the following 36 variables.
sorta numeric vector, sorting ID
UniqueIDa factor, unique location ID
SurveyDatea factor, date as DD-Mmm-YY
Timea factor, time in 12h clock format
Visita numeric vector, visit to same location
Observera factor with the observers' initials
SurveyTypea factor with levels
ARU (automated recoring unit) HUM (human observer)
NoiseLevela factor with levels Heavy Light Moderate None Unusable
SPECIESa factor with levels for species, 4-letter codes follow the AOU listhttps://www.birdpop.org/pages/birdSpeciesCodes.php
Counta numeric vector, number of individuals counted
TimeIntervala factor, original interval the individual was detected
DISTANCEa factor with levels >100 m 0-49 m 50-100 m ARU
FIDa numeric vector
Strataa factor
Stationa factor
Latitudea numeric vector
Longitudea numeric vector
Join_Counta numeric vector
YearLossa numeric vector
Class_Namea factor, ModisLCC description.
ModisLCCa numeric vector
FIRENAMEa factor
YEARa numeric vector
Disturbancea factor with levels Cutblock Fire Undisturbed
PKEYa factor
PKEYma factor, PKEY with method
Noisea numeric vector
JULIANa numeric vector
JDAYa numeric vector
srisea numeric vector
start_timea numeric vector
TSSRa numeric vector
Intervala factor with levels
0-3 min 3-5 min 5-10 min UNK
SSa factor
RandomSela numeric vector
Van Wilgenburg et al. 2016.
Van Wilgenburg, S. L., P. Solymos, K. J. Kardynal, and M. D. Frey. 2017. Paired sampling standardizes point count data from humans and acoustic recorders. Avian Conservation and Ecology 12(1):13. <doi:10.5751/ACE-00975-120113>
data(paired) str(paired)data(paired) str(paired)